function [ret,x0,str,ts,xts]=chap_sim(t,x,u,flag);
%CHAP_SIM	is the M-file description of the SIMULINK system named CHAP_SIM.
%	The block-diagram can be displayed by typing: CHAP_SIM.
%
%	SYS=CHAP_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CHAP_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CHAP_SIM with a FLAG of zero:
%	[SIZES]=CHAP_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[35,83,939,680])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     'X0')
set_param(sys,'Min step size', '0.005')
set_param(sys,'Max step size', '0.005')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['LES DONNEES D''INITIALISATION DOIVENT TRE MODIFIEES DANS CHAP_DAT.M',13,'']])
set_param([sys,'/',['LES DONNEES D''INITIALISATION DOIVENT TRE MODIFIEES DANS CHAP_DAT.M',13,'']],...
		'ForeGround',6,...
		'Font Size',16,...
		'position',[445,500,450,505])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','vitesse',...
		'buffer','2000',...
		'position',[670,457,720,473])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','D',...
		'buffer','2000',...
		'position',[670,422,720,438])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','gamma',...
		'buffer','2000',...
		'position',[670,377,720,393])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nqui excute chap_dat.m',...
		'Mask Dialogue','eval(''chap_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'BackGround',6,...
		'hide name',0,...
		'position',[190,405,410,461])

add_block('built-in/Stop Simulation',[sys,'/','Stop Simulation'])
set_param([sys,'/','Stop Simulation'],...
		'BackGround',6,...
		'hide name',0,...
		'position',[670,223,710,257])

add_block('built-in/Scope',[sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'hide name',0,...
		'Vgain','4000.000000',...
		'Hgain','2.000000',...
		'Vmax','8000.000000',...
		'Hmax','4.000000',...
		'Window',[496,398,827,712],...
		'position',[735,465,765,495])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn9'])
set_param([sys,'/','MATLAB Fcn9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(1)/cos(asin((u(2)/u(1)+u(3))/coeff))*(Mumars/(Rmars+Z0))^0.5',...
		'Output Width','1',...
		'position',[570,463,630,497])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn8'])
set_param([sys,'/','MATLAB Fcn8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(4)/1000',...
		'Output Width','1',...
		'position',[570,413,630,447])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn7'])
set_param([sys,'/','MATLAB Fcn7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','asin((u(2)/u(1)+u(3))/coeff)*180/pi',...
		'Output Width','1',...
		'position',[570,368,630,402])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'hide name',0,...
		'Vgain','150.000000',...
		'Hgain','2.000000',...
		'Vmax','300.000000',...
		'Hmax','4.000000',...
		'Window',[496,398,827,712],...
		'position',[730,175,760,205])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn6'])
set_param([sys,'/','MATLAB Fcn6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(5)',...
		'Output Width','1',...
		'position',[565,323,625,357])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn4'])
set_param([sys,'/','MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','acc(u)',...
		'Output Width','1',...
		'position',[565,273,625,307])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','altitude',...
		'buffer','2000',...
		'position',[665,197,715,213])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2000',...
		'position',[670,332,720,348])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','12.000000',...
		'Vmax','20.000000',...
		'Hmax','24.000000',...
		'Window',[496,398,827,712])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[730,255,760,285])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','accel',...
		'buffer','2000',...
		'position',[665,282,715,298])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','stopchap(u)',...
		'Output Width','1',...
		'position',[565,223,625,257])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','(log(u(1)/u(2)*SCxM*rho*(Rm/B)^0.5/2))/B/1000',...
		'Output Width','1',...
		'position',[560,178,620,212])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[496,398,827,712],...
		'position',[725,130,755,160])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(2)',...
		'Output Width','1',...
		'position',[560,138,620,172])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','Y',...
		'buffer','2000',...
		'position',[660,147,710,163])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'hide name',0,...
		'Vgain','1.000000',...
		'Hgain','10.000000',...
		'Vmax','2.000000',...
		'Hmax','20.000000',...
		'Window',[496,398,827,712],...
		'position',[725,75,755,105])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Yprime',...
		'buffer','2000',...
		'position',[660,97,710,113])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn5'])
set_param([sys,'/','MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[560,88,620,122])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','[1 4]',...
		'position',[220,193,260,342])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'ForeGround',1,...
		'BackGround',5,...
		'position',[145,184,160,271])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'ForeGround',1,...
		'BackGround',5,...
		'Gain','-1',...
		'position',[90,238,130,262])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',5,...
		'Value','X0',...
		'position',[50,195,70,215])

add_block('built-in/Clock',[sys,'/','t'])
set_param([sys,'/','t'],...
		'ForeGround',1,...
		'BackGround',5,...
		'position',[40,234,70,266])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','chap_sys(u)',...
		'Output Width','4',...
		'position',[280,253,340,287])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[370,249,395,291])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','[1 4]',...
		'position',[450,134,490,256])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','X',...
		'buffer','2000',...
		'position',[225,132,275,148])

add_block('built-in/Note',[sys,'/',['RENTREE MARTIENNE',13,'PAR LA THEORIE DE CHAPMAN']])
set_param([sys,'/',['RENTREE MARTIENNE',13,'PAR LA THEORIE DE CHAPMAN']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[395,10,400,15])
add_line(sys,[400,270;430,270;430,365;165,365;165,305;215,305])
add_line(sys,[345,270;365,270])
add_line(sys,[430,270;430,225;445,225])
add_line(sys,[75,250;85,250])
add_line(sys,[75,205;140,205])
add_line(sys,[135,250;140,250])
add_line(sys,[165,230;215,230])
add_line(sys,[265,270;275,270])
add_line(sys,[185,230;185,165;445,165])
add_line(sys,[495,195;520,195;520,105;555,105])
add_line(sys,[625,155;655,155])
add_line(sys,[625,155;625,145;720,145])
add_line(sys,[185,165;185,140;220,140])
add_line(sys,[625,195;625,190;725,190])
add_line(sys,[630,240;665,240])
add_line(sys,[520,195;520,290;560,290])
add_line(sys,[630,290;660,290])
add_line(sys,[630,290;635,270;725,270])
add_line(sys,[625,105;655,105])
add_line(sys,[625,105;625,90;720,90])
add_line(sys,[520,155;555,155])
add_line(sys,[520,195;555,195])
add_line(sys,[520,240;560,240])
add_line(sys,[520,290;520,340;560,340])
add_line(sys,[630,340;665,340])
add_line(sys,[625,195;625,205;660,205])
add_line(sys,[635,385;665,385])
add_line(sys,[520,340;520,385;565,385])
add_line(sys,[520,385;520,430;565,430])
add_line(sys,[635,430;665,430])
add_line(sys,[520,430;520,480;565,480])
add_line(sys,[635,480;730,480])
add_line(sys,[635,480;645,465;665,465])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
