function [ret,x0,str,ts,xts]=mars_sim(t,x,u,flag);
%MARS_SIM	is the M-file description of the SIMULINK system named MARS_SIM.
%	The block-diagram can be displayed by typing: MARS_SIM.
%
%	SYS=MARS_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MARS_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MARS_SIM with a FLAG of zero:
%	[SIZES]=MARS_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[198,53,916,546])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '500')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[435,180,455,200])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','2000',...
		'position',[515,180,585,200])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Vgain','140.000000',...
		'Hgain','1500.000000',...
		'Vmax','280.000000',...
		'Hmax','3000.000000',...
		'Window',[78,384,409,698],...
		'position',[595,235,625,265])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','accel',...
		'buffer','2000',...
		'position',[290,185,355,205])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','derivsys(u)',...
		'Output Width','4',...
		'position',[70,238,130,272])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'hide name',0,...
		'MATLAB Fcn','-u(1)/9.81',...
		'Output Width','1',...
		'position',[185,178,245,212])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[260,239,300,271])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','u(3)/1000',...
		'Output Width','1',...
		'position',[405,268,465,302])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','altitude',...
		'buffer','2000',...
		'position',[530,278,595,292])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION SIMULATION\npar double clic souris\nLACEMENT DE MARS_DAT.M',...
		'Mask Dialogue','eval(''mars_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',7,...
		'BackGround',5,...
		'hide name',0,...
		'position',[85,285,300,341])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn4'])
set_param([sys,'/','MATLAB Fcn4'],...
		'hide name',0,...
		'MATLAB Fcn','(u(3)<5000)|(u(1)<300)',...
		'Output Width','1',...
		'position',[210,408,270,442])

add_block('built-in/Stop Simulation',[sys,'/','Stop Simulation'])
set_param([sys,'/','Stop Simulation'],...
		'hide name',0,...
		'position',[295,408,335,442])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'hide name',0,...
		'Vgain','10000.000000',...
		'Hgain','1500.000000',...
		'Vmax','20000.000000',...
		'Hmax','3000.000000',...
		'Window',[378,278,709,592],...
		'position',[615,355,645,385])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn5'])
set_param([sys,'/','MATLAB Fcn5'],...
		'hide name',0,...
		'MATLAB Fcn','u(4)/1000',...
		'Output Width','1',...
		'position',[420,383,480,417])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','distance',...
		'buffer','2000',...
		'position',[545,393,610,407])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','vitesse',...
		'buffer','2000',...
		'position',[545,333,610,347])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','u(1)/1000',...
		'Output Width','1',...
		'position',[420,323,480,357])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','1500.000000',...
		'Vmax','20.000000',...
		'Hmax','3000.000000',...
		'Window',[582,449,913,763],...
		'position',[615,295,645,325])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','u',...
		'buffer','2000',...
		'position',[545,443,610,457])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn6'])
set_param([sys,'/','MATLAB Fcn6'],...
		'hide name',0,...
		'MATLAB Fcn','u(1)*((Rmars+u(3))/Mumars)^0.5',...
		'Output Width','1',...
		'position',[420,433,480,467])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'hide name',0,...
		'Vgain','8.000000',...
		'Hgain','1500.000000',...
		'Vmax','16.000000',...
		'Hmax','3000.000000',...
		'Window',[100,469,431,783])
open_system([sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'position',[375,135,405,165])

add_block('built-in/Note',[sys,'/',['RENTREE D''UN PLANEUR SUR MARS']])
set_param([sys,'/',['RENTREE D''UN PLANEUR SUR MARS']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',24,...
		'position',[395,5,400,10])

add_block('built-in/Note',[sys,'/',['Pour initialiser lancer mars_dat.m',13,'Conditions initiales rappeles dans l''espace de travail']])
set_param([sys,'/',['Pour initialiser lancer mars_dat.m',13,'Conditions initiales rappeles dans l''espace de travail']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['Pour initialiser lancer mars_dat.m',13,'Conditions initiales rappeles dans l''espace de travail']],...
		'position',[385,50,390,55])
add_line(sys,[460,190;510,190])
add_line(sys,[470,285;525,285])
add_line(sys,[485,285;485,250;590,250])
add_line(sys,[485,340;540,340])
add_line(sys,[500,340;500,310;610,310])
add_line(sys,[135,255;150,255;150,195;180,195])
add_line(sys,[250,195;285,195])
add_line(sys,[275,425;290,425])
add_line(sys,[150,255;255,255])
add_line(sys,[305,255;345,255;345,355;35,355;35,255;65,255])
add_line(sys,[345,285;400,285])
add_line(sys,[175,355;175,425;205,425])
add_line(sys,[345,355;345,400;415,400])
add_line(sys,[485,400;540,400])
add_line(sys,[500,400;500,370;610,370])
add_line(sys,[345,340;415,340])
add_line(sys,[345,400;345,450;415,450])
add_line(sys,[485,450;540,450])
add_line(sys,[260,195;260,150;370,150])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
